@@ -36,6 +36,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gio/gio.h>
 
 /* Macros */
 
@@ -622,6 +623,8 @@ const gchar *grl_source_get_id (GrlSource *source);
 
 const gchar *grl_source_get_name (GrlSource *source);
 
+GIcon *grl_source_get_icon (GrlSource *source);
+
 const gchar *grl_source_get_description (GrlSource *source);
 
 GrlPlugin *grl_source_get_plugin (GrlSource *source);
